@@ -3,12 +3,13 @@
 
 #include "fourimages.h"
 #include "ui_fourimages.h"
+#include "deletedialog.h"
+#include "ui_deletedialog.h"
 
 #include <QMainWindow>
 #include <QDir>
 #include <QLabel>
 #include <QPushButton>
-#include <QBoxLayout>
 #include <QListWidgetItem>
 
 namespace Ui {
@@ -50,12 +51,7 @@ private:
 
     QString delFileName;
     QFile delFileWithPath;
-    QDialog* delDialog;
-        QHBoxLayout* delLayoutH;
-        QVBoxLayout* delBtnsV;
-        QLabel* delText;
-        QPushButton* delYes;
-        QPushButton* delNo;
+    deleteDialog* delDialog;
     bool delDialogIsMade;
 
     QFile imageSetPrev;
@@ -64,7 +60,7 @@ private:
     fourImages* editWin;
     QFile editFile;
 
-    int curItemBeforeEdit;
+    int curRowBeforeEdit;
 };
 
 #endif // WPMANAGER_H
